<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="pt_BR">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy de Aplicativos</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de Proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Endereço de IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Selecione &quot;Usar Proxy&quot; no menu de contexto do Lançador, após a configuração</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço de IP inválido</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Porta inválida</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Excluir esta configuração?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Conexão Cabeada %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Conexão Wi-Fi %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Conexão PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nova VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Tipo de VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy de Aplicativos</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot Pessoal</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detalhes da Conexão de Rede</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do Sistema</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rede Cabeada</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede Wi-Fi</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo Avião</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Placa de Rede Cabeada</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Adicionar Conexão de Rede</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Placa de Rede Wi-Fi</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectar-se à rede oculta</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Criar Conexão PPPoE</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Status da VPN</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Criar VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importar VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de Proxy</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuração</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Endereço de IP</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Criar Hotspot</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Frequência</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Primário</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de Sub-rede</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo Avião</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Endereço DNS inválido</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Não Vincular</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Endereço MAC do Dispositivo</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Endereço MAC Clonado</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizar a MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>O nome já existe</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Conectar automaticamente</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Adicionar Configurações</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Criar Hotspot</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Endereço de IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Endereço de IP duplicado</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço de IP inválido</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de Sub-rede inválida</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Apenas um gateway é permitido</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de Sub-rede</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Endereço de IP duplicado</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço de IP inválido</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Apenas um gateway é permitido</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Endereço de IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Aplicado apenas em recursos correspondentes</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de Sub-rede</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço de IP inválido</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de Sub-rede inválida</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Detalhes da Conexão de Rede</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do Sistema</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy de Aplicativos</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo Avião</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detalhes da Conexão de Rede</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Configurar pelo Gerenciador de Rede</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot Pessoal</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Serviço</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Recusar a Autenticação EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Recusar a Autenticação PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Recusar a Autenticação CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Recusar a Autenticação MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Recusar a Autenticação MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Nenhuma Compressão de Dados BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Nenhuma Compressão de Dado Deflacionado</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Nenhuma Compressão de Cabeçalho TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nenhuma Compressão do Campo de Protocolo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nenhum Endereço/Controle de Compressão</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar Pacotes de Echo PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usar MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE 128-bit</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE com Estado</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Criar uma Conexão PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do Sistema</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de Proxy</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proxy HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignorar as configurações de proxy para os hosts e domínios acima</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuração</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>RÁPIDO</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS em túnel</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP Protegido</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Salvar senha para este usuário</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Salvar senha para todos os usuários</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Sempre perguntar</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anônimo</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autenticado</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Ambos</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versão 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versão 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Autenticação EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identidade</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opções de Senha</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave Privada</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de Usuário</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID Anônimo</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisionamento</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Arquivo PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Autenticação Interna</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versão PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Senha Privada</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Senha inválida</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Pessoal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Pessoal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chave</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Segurança Necessária</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Senha inválida</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Pessoal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Empresarial</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Pessoal</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Chave compartilhada</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Sistema aberto</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticação</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chave</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avançada</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Personalizar a Porta do Gateway</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Porta do Gateway</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Personalizar o Intervalo de Renegociação</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Intervalo de Renegociação</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Usar a Compressão de Dados LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Usar a Conexão TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Usar o Dispositivo TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Personalizar o Túnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Personalizar o Tamanho do Fragmento UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Tamanho do Fragmento UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restringir o Túnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Hosts Remotos Aleatórios</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avançada</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (padrão)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Seguro (padrão)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Fraco</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Quando Disponível (padrão)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Sempre NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>UDP Cisco</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>Grupo DH 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>Grupo DH 2 (padrão)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>Grupo DH 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Servidor (padrão)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>Grupo DH 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domínio</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Fabricante</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Criptografia</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Modo NAT Traversal</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grupo DH IKE</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Segredo Futuro</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Porta Local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Desativar a Detecção de Par Morto</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nome do Grupo</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID do Grupo</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chave Pré-compartilhada</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmos Phase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmos Phase2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Permitir o Trojan do Cisco Secure Desktop</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de Usuário</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave Privada</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Usar o FSID para a Dica de Senha</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificados (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificados com Senha (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Chave Estática</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Salvo</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Perguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Não Obrigatório</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo de Autenticação</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de Usuário</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave Privada</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opções de Senha</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Senha Privada</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalizar a Direção da Chave</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Direção da Chave</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP Remoto</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP Local</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Todas disponíveis (padrão)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (menos seguro)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (mais seguro)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Recusar a Autenticação EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Recusar a Autenticação PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Recusar a Autenticação CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Recusar a Autenticação MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Recusar a Autenticação MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Nenhuma Compressão de Dados BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Nenhuma Compressão de Dado Deflacionado</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Nenhuma Compressão de Cabeçalho TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nenhuma Compressão do Campo de Protocolo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nenhum Endereço/Controle de Compressão</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar Pacotes de Echo PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usar MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE com Estado</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Status da VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Criar VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importar VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Erro de Importação</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Erro de arquivo</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Não Obrigatório</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP do Servidor</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Tentar Indefinidamente Quando Falhar</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Arquivo CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignorar Avisos de Certificado</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Usar as Extensões do TLS Hostname</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Segurança VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Criptografia</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Autenticação HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Salvo</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Perguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Não Obrigatório</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opções de Senha</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domínio NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP do Servidor</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave Privada</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Cartão Inteligente</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chave Pré-compartilhada</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo de Autenticação</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de Usuário</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Solicitar um endereço de IP interno</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Forçar o Encapsulamento UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Usar a Compressão de IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Ativar as Sugestões de Codificação Personalizada</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autenticação VPN TLS</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Assunto Relacionado</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipo de Certificado Remoto</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Arquivo Chave</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalizar a Direção da Chave</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Direção da Chave</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Salvo</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Perguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Não Obrigatório</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opções de Senha</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nome do Grupo</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Senha do Grupo</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Use a Autenticação Híbrida</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Arquivo CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Conecte o cabo de rede</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Placa de Rede Cabeada</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Adicionar Conexão de Rede</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Selecionar Configurações</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Placa de Rede Wi-Fi</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Fechar Hotspot</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Desative o hotspot para conectar-se ao Wi-Fi</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectar-se à rede oculta</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Não Vincular</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Endereço MAC do Dispositivo</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizar a MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>